@@ -1,19 +1,27 @@
 package Debug::Client;
 
-use 5.008;
+use 5.008005;
 use strict;
 use warnings;
 
-our $VERSION = '0.13_10';
+our $VERSION = '0.17_01';
 
 use utf8;
 use IO::Socket;
 use Carp qw(carp croak cluck);
 
+use constant {
+	BLANK => qq{ },
+};
+
 =head1 NAME
 
 Debug::Client - client side code for perl debugger
 
+development version 0.17_01 for testing only!
+
+thanks cpan testers :)
+
 =head1 SYNOPIS
 
   use Debug::Client;
@@ -142,7 +150,7 @@ sub new {
 
 =head1 Warning sub listen has bean deprecated
 
-Has bean deprecated in this version 0.13_04 and all future versions starting with v0.14
+Has bean deprecated since 0.13_04 and all future versions starting with v0.14
 
 Perl::Critic Error Subroutine name is a homonym for built-in function
 
@@ -150,11 +158,11 @@ Use $debugger->listener instead
 
 =cut
 
-sub listen {
-	my ( $self, @args ) = @_;
-	$self->listener(@args);
-	return;
-}
+# sub listen {
+# my ( $self, @args ) = @_;
+# $self->listener(@args);
+# return;
+# }
 
 =head2 listener
 
@@ -616,10 +624,9 @@ value of that reference?
 # or its user) should actually call   x $var
 sub get_value {
 	my ( $self, $var ) = @_;
-	carp "no parameter given\n" if not defined $var;
 
-	if ( $var =~ /^\$/ ) {
-		$self->_send("p $var");
+	if ( not defined $var ) {
+		$self->_send('p');
 		my $buf = $self->_get;
 		$self->_prompt( \$buf );
 		return $buf;
@@ -629,9 +636,12 @@ sub get_value {
 		$self->_prompt( \$buf );
 		my $data_ref = _parse_dumper($buf);
 		return $data_ref;
+	} else {
+		$self->_send("p $var");
+		my $buf = $self->_get;
+		$self->_prompt( \$buf );
+		return $buf;
 	}
-	carp "Unknown parameter '$var'\n";
-	return;
 }
 
 =head2 get_p_exp
@@ -657,10 +667,6 @@ From perldebug, but defaulted to y 0
 sub get_p_exp {
 	my ( $self, $exp ) = @_;
 
-	unless ( defined $exp ) {
-		return;
-	}
-
 	$self->_send("p $exp");
 	my $buf = $self->_get;
 	$self->_prompt( \$buf );
@@ -764,14 +770,6 @@ For more help, type h cmd_letter, optional var
 sub get_h_var {
 	my ( $self, $var ) = @_;
 
-	# $self->_send('h');
-	# my $buf = $self->_get;
-
-	# # 	$self->_prompt( \$buf );
-	# $buf =~ s/(\e\[4m|\e\[24m|\e\[1m|\e\[0m)//mg;
-
-	# # 	# $buf =~ s/\e\[24m//mg;
-	# return $buf;
 	if ( defined $var ) {
 		$self->_send("h $var");
 	} else {
@@ -784,6 +782,64 @@ sub get_h_var {
 	return $buf;
 }
 
+=head2 set_option
+
+o booloption ...
+
+Set each listed Boolean option to the value 1 .
+o anyoption? ...
+
+Print out the value of one or more options.
+o option=value ...
+
+Set the value of one or more options. If the value has internal whitespace, it should be quoted. For example, you could set o pager="less -MQeicsNfr" to call less with those specific options. You may use either single or double quotes, but if you do, you must escape any embedded instances of same sort of quote you began with, as well as any escaping any escapes that immediately precede that quote but which are not meant to escape the quote itself. In other words, you follow single-quoting rules irrespective of the quote; eg: o option='this isn\'t bad' or o option="She said, \"Isn't it?\"" .
+
+For historical reasons, the =value is optional, but defaults to 1 only where it is safe to do so--that is, mostly for Boolean options. It is always better to assign a specific value using = . The option can be abbreviated, but for clarity probably should not be. Several options can be set together. See Configurable Options for a list of these.
+
+ $debugger->set_option();
+
+=cut
+
+#######
+# Internal Method _set_option
+#######
+sub set_option {
+	my ( $self, $option ) = @_;
+
+	unless ( defined $option ) {
+		return;
+	}
+
+	$self->_send("o $option");
+	my $buf = $self->_get;
+	$self->_prompt( \$buf );
+	return $buf;
+
+}
+
+=head2 get_options
+
+o
+
+Display all options.
+
+ $debugger->get_options();
+
+=cut
+
+#######
+# Internal Method _get_options
+#######
+sub get_options {
+	my $self = shift;
+
+	$self->_send('o');
+	my $buf = $self->_get;
+	$self->_prompt( \$buf );
+	return $buf;
+
+}
+
 =head2 get
 
 Actually I think this is an internal method....
@@ -825,6 +881,7 @@ sub get {
 #######
 sub filename {
 	my $self = shift;
+
 	return $self->{filename};
 }
 
@@ -839,9 +896,24 @@ sub filename {
 #######
 sub row {
 	my $self = shift;
+
 	return $self->{row};
 }
 
+=head2 module
+
+ $debugger->module();
+
+=cut
+
+#######
+# Method module
+#######
+sub module {
+	my $self = shift;
+
+	return $self->{module};
+}
 #########################################
 #### Internal Methods
 #######
@@ -914,8 +986,13 @@ sub _process_line {
 	}
 
 	my @parts = split /\n/, $$buf;
-
-	my $line = pop @parts;
+	
+	my $line = BLANK;
+	my $module  = BLANK;
+	my $file    = BLANK;
+	my $row     = BLANK;
+	my $content = BLANK;
+	$line = pop @parts;
 
 	#TODO $line is where all CPAN_Testers errors come from
 	# try to debug some test reports
@@ -930,18 +1007,22 @@ sub _process_line {
 		if ( $line =~ /^\d+:   \s*  (.*)$/x ) {
 			$cont = $1;
 			$line = pop @parts;
+			# my $next_line = pop @parts;
+		# if ( defined $next_line ) {
+			# $line = pop @parts;
+		# }
 
 			# _logger("Line2: $line");
 		}
 	}
 
 	$$buf = join "\n", @parts;
-	my ( $module, $file, $row, $content ) = q{ };
+	# my ( $module, $file, $row, $content ) = q{ };
 
 	# the last line before
 	# main::(t/eg/01-add.pl:8):  my $z = $x + $y;
 
-	if ($line =~ m{^([\w:]*) 			# module
+	if ( $line =~ m{^([\w:]*) 			# module
                   \( ([^\)]*):(\d+) \) 	# (file:row)
                   :\t? 					# :
                   (.*) 					# content
@@ -950,21 +1031,41 @@ sub _process_line {
 	{
 		( $module, $file, $row, $content ) = ( $1, $2, $3, $4 );
 	}
+	if ( $module eq BLANK || $file eq BLANK || $row eq BLANK ) {
 
+# 		# unless ( defined $module || defined $file || defined $row ) {
+		my $current_file = $self->show_line();
+		# p $current_file;
+
+		$current_file =~ m/^([\w:]*) \( (.*) : (\d+) .* /mx;
+
+		$module  = $1;
+		$file    = $2;
+		$row     = $3;
+		# p $module;
+		# p $file;
+		# p $row;
+	}
+	
 	if ($cont) {
 		$content = $cont;
 	}
 
-	if ($file) {
+	# if ($file) {
 
-		$self->{filename} = $file;
+# # 		$self->{filename} = $file;
 
-		# print "filename: $self->{filename}\n";
-	}
+# # 		# print "filename: $self->{filename}\n";
+	# }	
+	$self->{module}   = $module;
+	$self->{filename} = $file;
 	$self->{row} = $row;
 	return ( $module, $file, $row, $content );
 }
 
+
+
+
 #######
 # Internal Method _prompt
 #######
@@ -1013,21 +1114,7 @@ sub _send_get {
 
 	return $self->get;
 }
-#######
-# Internal Method _set_option help
-#######
-sub _set_option {
-	my ( $self, $option ) = @_;
-	unless ( defined $option ) {
-		return;
-	}
 
-	$self->_send("o $option");
-	my $buf = $self->_get;
-	$self->_prompt( \$buf );
-	return $buf;
-
-}
 #######
 # Internal Method __send_padre
 # hidden undocumented
@@ -1093,8 +1180,6 @@ and just performing c on it's own
 
 =head3 _send_get
 
-=head3 _set_option
-
 =head1 AUTHORS
 
 Gabor Szabo E<lt>gabor@szabgab.comE<gt>
